==> nextcloud-27.1.11.tgz: nextcloud/apps/activity/l10n/nb.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Personlig aktivitetsstrøm for %s",
    "Your feed URL is invalid" : "Nettadressen for din strøm er ikke gyldig",
    "Activity feed for %1$s" : "Aktivitetsstrøm for %1$s",
    "Activity feed" : "Aktivitetsstrøm",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "Settings have been updated." : "Innstillinger oppdatert.",
    "Recent activity" : "Nylig aktivitet",
    "No activities" : "Ingen aktiviteter",
    "More activities" : "Flere aktiviteter",
    "Daily activity summary for %s" : "Daglig aktivitetssammendrag for %s",
    "_and %n more _::_and %n more _" : ["og %n til","og %n til"],
    "All activities" : "All aktivitet",
    "By others" : "Av andre",
    "By you" : "Av deg",
    "Activity at %s" : "Aktivitet på %s",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "Det har vært aktivitet ved %s",
    "Mail" : "E-post",
    "Push" : "Push",
    "Activity" : "Aktivitet",
    "Notifications" : "Varsler",
    "This application enables people to view a log of activities about them, their files or other data." : "Denne applikasjonen gjør brukere istand til å se deres logg av aktiviteter, filer og annen data.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Denne appen lar folk se handlinger relatert til filene og dataene deres i Nextcloud.\n\t\tHver person kan konfigurere sine individuelle aktivitetsinnstillinger i de personlige innstillingene,\n\t\tfor å velge hvilken aktivitet som skal sendes til mobiltelefoner, sendt via e-post\n\t\teller om en daglig oppsummering sendes hver morgen.\n\t\tMer informasjon er tilgjengelig i dokumentasjonen for Aktivitet.",
    "Activity notification configuration" : "Konfigurering av aktivitetsvarsling",
    "Send email" : "Send e-post",
    "Send push notification" : "Send push-varsling",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
    "Send activity emails" : "Send aktivitets-e-poster",
    "As soon as possible" : "Så snart som mulig",
    "Hourly" : "Hver time",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "You commented" : "Du kommenterte",
    "Message deleted by author" : "Melding slettet av forfatteren",
    "Open {filename}" : "Åpne {filename}",
    "in {path}" : "i {path}",
    "Home" : "Hjem",
    "Loading activities" : "Laster aktiviteter",
    "This stream will show events like additions, changes & shares" : "Denne strømmen vil vise hendelser som f.eks. innlegging, endring og deling",
    "No activity yet" : "Ingen aktivitet ennå",
    "Loading more activities" : "Laster flere aktiviteter",
    "No more activities." : "Ingen flere aktiviteter.",
    "Could not load activities" : "Kunne ikke laste aktiviteter",
    "Activity settings" : "Aktivitetsinnstillinger",
    "Enable RSS feed" : "Skru på RSS-strøm",
    "RSS feed" : "RSS-strøm",
    "Copy RSS feed link" : "Kopier RSS lenke",
    "Personal notification settings" : "Personlige innstillinger for varsler",
    "Could not enable RSS link" : "Kunne ikke aktivere RSS-lenke",
    "RSS link copied to clipboard" : "RSS-lenke kopiert til utklippstavlen",
    "Could not copy the RSS link, please copy manually:" : "Kunne ikke kopiere RSS-lenken, vennligst kopier manuelt:",
    "Unable to load the activity list" : "Kunne ikke laste aktivitetslisten",
    "Notification" : "Varsel",
    "Enable notification emails" : "Aktiver e-post notifikasjoner",
    "Choose for which activities you want to get an email or push notification." : "Velg hvilke aktiviteter du vil motta via e-post eller via push-varsel.",
    "Choose for which activities you want to get a push notification." : "Velg hvilke aktiviteter du vil motta et push-varsel for.",
    "Daily activity summary" : "Daglig oppsummering for aktiviteter",
    "Send daily activity summary in the morning" : "Send daglig aktivitetssammendrag om morgenen",
    "Default settings" : "Standard innstillinger",
    "Configure the default notification settings for new accounts." : "Konfigurer standard varslingsinnstillinger for nye kontoer.",
    "Unable to save the settings" : "Klarte ikke å lagre innstillingene",
    "No more events to load" : "Ingen flere hendelser å laste inn",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "There are no events for this filter" : "Det er ingen hendelser for dette filteret",
    "Could not load activites" : "Kunne ikke laste aktiviteter"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/activity/l10n/nb.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Personlig aktivitetsstrøm for %s",
    "Your feed URL is invalid" : "Nettadressen for din strøm er ikke gyldig",
    "Activity feed for %1$s" : "Aktivitetsstrøm for %1$s",
    "Activity feed" : "Aktivitetsstrøm",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "Settings have been updated." : "Innstillinger oppdatert.",
    "Recent activity" : "Nylig aktivitet",
    "No activities" : "Ingen aktiviteter",
    "More activities" : "Flere aktiviteter",
    "Daily activity summary for %s" : "Daglig aktivitetssammendrag for %s",
    "_and %n more…_::_and %n more…_" : ["og %n til…","og %n til…"],
    "All activities" : "All aktivitet",
    "By others" : "Av andre",
    "By you" : "Av deg",
    "Activity at %s" : "Aktivitet på %s",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "Det har vært aktivitet ved %s",
    "_and %n more _::_and %n more _" : ["og %n til","og %n til"],
    "Mail" : "E-post",
    "Push" : "Push",
    "Activity" : "Aktivitet",
    "Notifications" : "Varsler",
    "This application enables people to view a log of activities about them, their files or other data." : "Denne applikasjonen gjør brukere istand til å se deres logg av aktiviteter, filer og annen data.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Denne appen lar folk se handlinger relatert til filene og dataene deres i Nextcloud.\n\t\tHver person kan konfigurere sine individuelle aktivitetsinnstillinger i de personlige innstillingene,\n\t\tfor å velge hvilken aktivitet som skal sendes til mobiltelefoner, sendt via e-post\n\t\teller om en daglig oppsummering sendes hver morgen.\n\t\tMer informasjon er tilgjengelig i dokumentasjonen for Aktivitet.",
    "Activity notification configuration" : "Konfigurering av aktivitetsvarsling",
    "Send email" : "Send e-post",
    "Send push notification" : "Send push-varsling",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
    "Send activity emails" : "Send aktivitets-e-poster",
    "As soon as possible" : "Så snart som mulig",
    "Hourly" : "Hver time",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "You commented" : "Du kommenterte",
    "Message deleted by author" : "Melding slettet av forfatteren",
    "Open {filename}" : "Åpne {filename}",
    "in {path}" : "i {path}",
    "Home" : "Hjem",
    "Loading activities" : "Laster aktiviteter",
    "This stream will show events like additions, changes & shares" : "Denne strømmen vil vise hendelser som f.eks. innlegging, endring og deling",
    "No activity yet" : "Ingen aktivitet ennå",
    "Loading more activities" : "Laster flere aktiviteter",
    "No more activities." : "Ingen flere aktiviteter.",
    "Could not load activities" : "Kunne ikke laste aktiviteter",
    "Activity settings" : "Aktivitetsinnstillinger",
    "Enable RSS feed" : "Skru på RSS-strøm",
    "RSS feed" : "RSS-strøm",
    "Copy RSS feed link" : "Kopier RSS lenke",
    "Personal notification settings" : "Personlige innstillinger for varsler",
    "Could not enable RSS link" : "Kunne ikke aktivere RSS-lenke",
    "RSS link copied to clipboard" : "RSS-lenke kopiert til utklippstavlen",
    "Could not copy the RSS link, please copy manually:" : "Kunne ikke kopiere RSS-lenken, vennligst kopier manuelt:",
    "Unable to load the activity list" : "Kunne ikke laste aktivitetslisten",
    "Notification" : "Varsel",
    "Enable notification emails" : "Aktiver e-post notifikasjoner",
    "Choose for which activities you want to get an email or push notification." : "Velg hvilke aktiviteter du vil motta via e-post eller via push-varsel.",
    "Choose for which activities you want to get a push notification." : "Velg hvilke aktiviteter du vil motta et push-varsel for.",
    "Daily activity summary" : "Daglig oppsummering for aktiviteter",
    "Send daily activity summary in the morning" : "Send daglig aktivitetssammendrag om morgenen",
    "Default settings" : "Standard innstillinger",
    "Configure the default notification settings for new accounts." : "Konfigurer standard varslingsinnstillinger for nye kontoer.",
    "Unable to save the settings" : "Klarte ikke å lagre innstillingene",
    "No more events to load" : "Ingen flere hendelser å laste inn",
    "Could not load activites" : "Kunne ikke laste aktiviteter"
},
"nplurals=2; plural=(n != 1);");
